@@ -125,15 +125,27 @@ class PortfolioHandler(DBHandler):
     def user_id(self) -> str:
         return self['user_id']
 
+    @user_id.setter
+    def user_id(self, _user_id:str):
+        self['user_id'] = _user_id
+
     @property
     def exchange(self) -> str:
         return self['exchange']
-        # """
-        #     self['user_id']
-        #     self['exchange']
-        #     self['episode']
-        #     self['live']
-        # """
+    
+    @exchange.setter
+    def exchange(self, _exchange:str):
+        self['exchange'] = _exchange
+
+
+    @property
+    def episode(self) -> str:
+        return self['episode']
+    
+    @episode.setter
+    def episode(self, _episode:str):
+        self['episode'] = _episode
+        
 
     @property
     def holdings(self):
